DiplomatStr16Slice

Type Alias DiplomatStr16Slice 

pub type DiplomatStr16Slice<'a> = DiplomatSlice<'a, u16>;
An unvalidated UTF-16 string that is safe to use over FFI

This type will usually map to some string type in the target language, and you will not need to worry about the safety of mismatched string invariants.

Aliased Type

#[repr(C)]
pub struct DiplomatStr16Slice<'a> { ptr: *const u16, len: usize, phantom: PhantomData<&'a [u16]>, }

Fields

ptr: *const u16len: usizephantom: PhantomData<&'a [u16]>